@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08220_02';
+our $VERSION = '0.08320_02';
 
 require 5.006;
 
@@ -32,6 +32,7 @@ use File::Glob 'bsd_glob';
 use Class::Struct; #in core since 5.004
 use Data::Dumper;
 use File::Basename qw( dirname );
+use Text::ParseWords qw( shellwords );
 
 our $UseDebugging;
 
@@ -410,6 +411,10 @@ sub _pc_var {
     return $$glob;
 }
 
+sub _quote_cvt($)  {
+    join ' ', map { s/(\s|"|')/\\$1/g; $_ } shellwords(shift)
+}
+
 sub assign_var {
     my ($self,$field,$value) = @_;
     no strict 'refs';
@@ -419,7 +424,7 @@ sub assign_var {
         log_debug("Prefix already defined by user");
         return;
     }
-    my $evalstr = sprintf('$%s = %s',
+    my $evalstr = sprintf('$%s = PkgConfig::_quote_cvt(%s)',
                     $self->_get_pc_varname($field), $value);
     
     log_debug("EVAL", $evalstr);
@@ -615,7 +620,7 @@ sub get_requires {
 sub parse_line {
     my ($self,$line,$evals) = @_;
     no strict 'vars';
-    
+
     $line =~ s/#[^#]+$//g; # strip comments
     return unless $line;
     
@@ -656,14 +661,17 @@ sub parse_line {
     
     $value =~ s/\$\{/\$\{$varclass\::/g;
     
+    # preserve quoted space
+    $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
+      if $value =~ /[\\"']/;
+    
     #quoute the value string, unless quouted already
-    $value = "\"$value\"" unless $value =~ /^["']/;
+    $value = "\"$value\"";
     
     #get existent variables from our hash:
     
     
-    $value =~ s/'/"/g; #allow for interpolation
-    
+    #$value =~ s/'/"/g; #allow for interpolation
     $self->assign_var($field, $value);
     
 }
@@ -778,13 +786,17 @@ sub find_pcfile {
 ################################################################################
 ################################################################################
 
+sub _return_context (@) {
+    wantarray ? (@_) : join(' ', map { s/(\s|['"])/\\$1/g; $_ } @_)
+}
+
 sub get_cflags {
     my $self = shift;
     my @cflags = @{$self->cflags};
 
     filter_omit(\@cflags, $self->exclude_cflags);
     filter_dups(\@cflags);
-    return @cflags;
+    _return_context @cflags;
 }
 
 sub get_ldflags {
@@ -804,7 +816,7 @@ sub get_ldflags {
     @ret = reverse @ret;
     filter_dups(\@ret);
     @ret = reverse(@ret);
-    return @ret;
+    _return_context @ret;
 }
 
 sub get_var {
@@ -845,7 +857,8 @@ sub _split_flags {
     if(@flags == 1) {
         my $str = shift @flags;
         return () if !$str;
-        @flags = split(/\s+/, $str);
+        #@flags = map { s/\\(\s)/$1/g; $_ } split(/(?<!\\)\s+/, $str);
+        @flags = shellwords $str;
     }
     @flags = grep $_, @flags;
     return @flags;
@@ -1150,7 +1163,7 @@ if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
     @print_flags = grep /^-[LR]/, $o->get_ldflags;
 }
 
-print $_, " " for @print_flags;
+print scalar PkgConfig::_return_context(@print_flags);
 print "\n";
 exit(0);
 
@@ -1404,7 +1417,15 @@ The version of the package
 
 =head4 I<< $o->get_ldflags >>
 
-Returns a list of compiler and linker flags, respectively.
+Returns compiler and linker flags, respectively.
+
+In list context, these methods return a list with each argument split on
+unescaped spaces.
+
+In list context returns a list of compiler and linker flags, respectively.
+
+In scalar context returns a string of compiler and linker flags with spaces
+and quotes escaped correctly.
 
 =head4 I<< $o->get_var($name) >>
 
